NpkModel class

Constructors

NpkModel({int id = -1, int status = -1, int amount = -1, String kind = '', String code = '', String created_at = '', String updated_at = '', String title = '', bool choose = false, bool lock = false, String image = ''})

Properties

amount int
getter/setter pair
choose bool
getter/setter pair
code String
getter/setter pair
created_at String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id int
getter/setter pair
image String
getter/setter pair
kind String
getter/setter pair
lock bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status int
getter/setter pair
title String
getter/setter pair
updated_at String
getter/setter pair

Methods

fromJson(Map json) NpkModel
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited