NpkResult class

Constructors

NpkResult({String weight = '', String rate = '', double mix = 0.0, double total = 0.0, required List<Manure> manures, required Result result})
NpkResult.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
manures List<Manure>
getter/setter pair
mix double
getter/setter pair
rate String
getter/setter pair
result Result
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
total double
getter/setter pair
weight String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited