Util_Npk class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Static Methods
-
addAction(BuildContext context, String buttonName, dynamic value, Color color, double elevation)
→ Widget
-
-
createItems(BuildContext context, String title, dynamic values, String id, {bool hasTitle = true})
→ List<Widget>
-
-
getValueFromJson(dynamic json, String key, dynamic defaultValue)
→ dynamic
-
-
goToNextPage(dynamic context, dynamic page, dynamic funCallback)
→ dynamic
-
-
goToPage(dynamic context, dynamic page, dynamic funCallback)
→ dynamic
-
-
hasDomain(String url)
→ bool
-
-
isNullFromJson(dynamic json, String key)
→ bool
-
-
showCustomAlertDialog(BuildContext context, String message, {String? title, bool isActionCancel = false, double elevation = 4.0, Color primaryColor = Colors.white54})
→ Future<bool?>
-
-
showOptionDialog(BuildContext context, String title, dynamic values, String id, {bool hasTitle = true, bool allowOff = true})
→ Future
-